@@ -54,6 +54,7 @@
 #include "gdkprivate-x11.h"
 #include "gdkdisplay-x11.h"
 #include "gdkscreen-x11.h"
+#include "gdkalias.h"
 
 typedef struct _GdkImagePrivateX11     GdkImagePrivateX11;
 
@@ -157,7 +158,7 @@ _gdk_image_exit (void)
  * Return value: a new #GdkImage.
  **/
 GdkImage *
-gdk_image_new_bitmap(GdkVisual *visual, gpointer data, gint width, gint height)
+gdk_image_new_bitmap (GdkVisual *visual, gpointer data, gint width, gint height)
 {
   Visual *xvisual;
   GdkImage *image;
@@ -182,18 +183,19 @@ gdk_image_new_bitmap(GdkVisual *visual, gpointer data, gint width, gint height)
       xvisual = ((GdkVisualPrivate*) visual)->xvisual;
       private->ximage = XCreateImage (GDK_SCREEN_XDISPLAY (private->screen),
 				      xvisual, 1, XYBitmap,
-				      0, 0, width, height, 8, 0);
+				      0, NULL, width, height, 8, 0);
+      private->ximage->data = data;
+      private->ximage->bitmap_bit_order = MSBFirst;
+      private->ximage->byte_order = MSBFirst;
     }
   
-  private->ximage->data = data;
-  private->ximage->bitmap_bit_order = MSBFirst;
-  private->ximage->byte_order = MSBFirst;
   image->byte_order = MSBFirst;
   image->mem =  private->ximage->data;
   image->bpl = private->ximage->bytes_per_line;
   image->bpp = 1;
-  return(image);
-} /* gdk_image_new_bitmap() */
+
+  return image;
+} 
 
 void
 _gdk_windowing_image_init (GdkDisplay *display)
@@ -317,7 +319,7 @@ _gdk_image_new_for_depth (GdkScreen    *screen,
 		}
 
 	      x_shm_info->readOnly = False;
-	      x_shm_info->shmaddr = shmat (x_shm_info->shmid, 0, 0);
+	      x_shm_info->shmaddr = shmat (x_shm_info->shmid, NULL, 0);
 	      private->ximage->data = x_shm_info->shmaddr;
 
 	      if (x_shm_info->shmaddr == (char*) -1)
@@ -349,7 +351,7 @@ _gdk_image_new_for_depth (GdkScreen    *screen,
 	       * we die in XShmAttach. In theory, a signal handler
 	       * could be set up.
 	       */
-	      shmctl (x_shm_info->shmid, IPC_RMID, 0);		      
+	      shmctl (x_shm_info->shmid, IPC_RMID, NULL);		      
 
 	      if (image)
 		image_list = g_list_prepend (image_list, image);
@@ -360,7 +362,7 @@ _gdk_image_new_for_depth (GdkScreen    *screen,
 	  break;
 	case GDK_IMAGE_NORMAL:
 	  private->ximage = XCreateImage (screen_x11->xdisplay, xvisual, depth,
-					  ZPixmap, 0, 0, width, height, 32, 0);
+					  ZPixmap, 0, NULL, width, height, 32, 0);
 
 	  /* Use malloc, not g_malloc here, because X will call free()
 	   * on this data
@@ -401,7 +403,7 @@ _gdk_image_new_for_depth (GdkScreen    *screen,
       if (x_shm_info->shmaddr != (char *)-1)
 	shmdt (x_shm_info->shmaddr);
       if (x_shm_info->shmid != -1) 
-	shmctl (x_shm_info->shmid, IPC_RMID, 0);
+	shmctl (x_shm_info->shmid, IPC_RMID, NULL);
       
       g_free (x_shm_info);
       private->x_shm_info = NULL;
@@ -839,3 +841,6 @@ _gdk_windowing_get_bits_for_depth (GdkDisplay *display,
   return -1;
 }
 
+
+#define __GDK_IMAGE_X11_C__
+#include "gdkaliasdef.c"
