@@ -33,27 +33,31 @@
 
 #include <gtk/gtkwidget.h>
 
+G_BEGIN_DECLS
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+typedef gchar * (*GtkTranslateFunc)	   (const gchar		*path,
+					    gpointer             func_data);
 
+#if !defined (GTK_DISABLE_DEPRECATED) || defined (GTK_COMPILATION)
 
 typedef void	(*GtkPrintFunc)		   (gpointer		 func_data,
 					    const gchar		*str);
-typedef gchar * (*GtkTranslateFunc)	   (const gchar		*path,
-					    gpointer             func_data);
+/* We use () here to mean unspecified arguments. This is deprecated
+ * as of C99, but we can't change it without breaking compatibility.
+ * (Note that if we are included from a C++ program () will mean
+ * (void) so an explicit cast will be needed.)
+ */
 typedef	void	(*GtkItemFactoryCallback)  ();
 typedef	void	(*GtkItemFactoryCallback1) (gpointer		 callback_data,
 					    guint		 callback_action,
 					    GtkWidget		*widget);
 
 #define GTK_TYPE_ITEM_FACTORY            (gtk_item_factory_get_type ())
-#define GTK_ITEM_FACTORY(object)         (GTK_CHECK_CAST ((object), GTK_TYPE_ITEM_FACTORY, GtkItemFactory))
-#define GTK_ITEM_FACTORY_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_ITEM_FACTORY, GtkItemFactoryClass))
-#define GTK_IS_ITEM_FACTORY(object)      (GTK_CHECK_TYPE ((object), GTK_TYPE_ITEM_FACTORY))
-#define GTK_IS_ITEM_FACTORY_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_ITEM_FACTORY))
-#define GTK_ITEM_FACTORY_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_ITEM_FACTORY, GtkItemFactoryClass))
+#define GTK_ITEM_FACTORY(object)         (G_TYPE_CHECK_INSTANCE_CAST ((object), GTK_TYPE_ITEM_FACTORY, GtkItemFactory))
+#define GTK_ITEM_FACTORY_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_ITEM_FACTORY, GtkItemFactoryClass))
+#define GTK_IS_ITEM_FACTORY(object)      (G_TYPE_CHECK_INSTANCE_TYPE ((object), GTK_TYPE_ITEM_FACTORY))
+#define GTK_IS_ITEM_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_ITEM_FACTORY))
+#define GTK_ITEM_FACTORY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_ITEM_FACTORY, GtkItemFactoryClass))
 
 
 typedef	struct	_GtkItemFactory			GtkItemFactory;
@@ -79,11 +83,13 @@ struct _GtkItemFactoryClass
 {
   GtkObjectClass	 object_class;
 
-  gchar			*cpair_comment_single;
-
   GHashTable		*item_ht;
 
-  gpointer               dummy;
+  /* Padding for future expansion */
+  void (*_gtk_reserved1) (void);
+  void (*_gtk_reserved2) (void);
+  void (*_gtk_reserved3) (void);
+  void (*_gtk_reserved4) (void);
 };
 
 struct _GtkItemFactoryEntry
@@ -122,42 +128,33 @@ struct _GtkItemFactoryEntry
 struct _GtkItemFactoryItem
 {
   gchar *path;
-  guint  accelerator_key;
-  guint  accelerator_mods;
-  guint	 modified : 1;
-  guint  in_propagation : 1;
-  gchar *dummy;
-
   GSList *widgets;
 };
 
 
-GtkType		gtk_item_factory_get_type	    (void) G_GNUC_CONST;
+GType		gtk_item_factory_get_type	    (void) G_GNUC_CONST;
 
 /* `container_type' must be of GTK_TYPE_MENU_BAR, GTK_TYPE_MENU,
  * or GTK_TYPE_OPTION_MENU.
  */
-GtkItemFactory*	gtk_item_factory_new	   (GtkType		 container_type,
+GtkItemFactory*	gtk_item_factory_new	   (GType		 container_type,
 					    const gchar		*path,
 					    GtkAccelGroup       *accel_group);
 void		gtk_item_factory_construct (GtkItemFactory	*ifactory,
-					    GtkType		 container_type,
+					    GType		 container_type,
 					    const gchar		*path,
 					    GtkAccelGroup       *accel_group);
      
 /* These functions operate on GtkItemFactoryClass basis.
  */
-void		gtk_item_factory_parse_rc	    (const gchar    *file_name);
-void		gtk_item_factory_parse_rc_string    (const gchar    *rc_string);
-void		gtk_item_factory_parse_rc_scanner   (GScanner	    *scanner);
 void		gtk_item_factory_add_foreign        (GtkWidget	    *accel_widget,
 						     const gchar    *full_path,
 						     GtkAccelGroup  *accel_group,
 						     guint	     keyval,
 						     GdkModifierType modifiers);
      
-GtkItemFactory*	gtk_item_factory_from_widget	    (GtkWidget	      *widget);
-gchar*		gtk_item_factory_path_from_widget   (GtkWidget	      *widget);
+GtkItemFactory*       gtk_item_factory_from_widget      (GtkWidget *widget);
+G_CONST_RETURN gchar* gtk_item_factory_path_from_widget (GtkWidget *widget);
 
 GtkWidget*	gtk_item_factory_get_item	      (GtkItemFactory *ifactory,
 						       const gchar    *path);
@@ -168,19 +165,6 @@ GtkWidget*	gtk_item_factory_get_widget_by_action (GtkItemFactory *ifactory,
 GtkWidget*	gtk_item_factory_get_item_by_action   (GtkItemFactory *ifactory,
 						       guint	       action);
 
-/* If `path_pspec' is passed as `NULL', this function will iterate over
- * all hash entries. otherwise only those entries will be dumped for which
- * the pattern matches, e.g. "<Image>*...".
- */
-void	gtk_item_factory_dump_items	(GPatternSpec		*path_pspec,
-					 gboolean		 modified_only,
-					 GtkPrintFunc		 print_func,
-					 gpointer		 func_data);
-void	gtk_item_factory_dump_rc	(const gchar		*file_name,
-					 GPatternSpec		*path_pspec,
-					 gboolean		 modified_only);
-void	gtk_item_factory_print_func	(gpointer		 FILE_pointer,
-					 const gchar		*string);
 void	gtk_item_factory_create_item	(GtkItemFactory		*ifactory,
 					 GtkItemFactoryEntry	*entry,
 					 gpointer		 callback_data,
@@ -200,14 +184,14 @@ void	gtk_item_factory_popup		(GtkItemFactory		*ifactory,
 					 guint			 x,
 					 guint			 y,
 					 guint			 mouse_button,
-					 guint32		 time);
+					 guint32		 time_);
 void	gtk_item_factory_popup_with_data(GtkItemFactory		*ifactory,
 					 gpointer		 popup_data,
 					 GtkDestroyNotify	 destroy,
 					 guint			 x,
 					 guint			 y,
 					 guint			 mouse_button,
-					 guint32		 time);
+					 guint32		 time_);
 gpointer gtk_item_factory_popup_data	(GtkItemFactory		*ifactory);
 gpointer gtk_item_factory_popup_data_from_widget (GtkWidget	*widget);
 void   gtk_item_factory_set_translate_func (GtkItemFactory      *ifactory,
@@ -215,9 +199,10 @@ void   gtk_item_factory_set_translate_func (GtkItemFactory      *ifactory,
 					    gpointer             data,
 					    GtkDestroyNotify     notify);
 
-#ifndef GTK_DISABLE_DEPRECATED
 /* Compatibility functions for deprecated GtkMenuFactory code
  */
+
+/* Used by gtk_item_factory_create_menu_entries () */
 typedef void (*GtkMenuCallback) (GtkWidget *widget,
 				 gpointer   user_data);
 typedef struct {
@@ -227,25 +212,29 @@ typedef struct {
   gpointer callback_data;
   GtkWidget *widget;
 } GtkMenuEntry;
-GtkItemFactory*	gtk_item_factory_from_path   (const gchar       *path);
-void	gtk_item_factory_create_menu_entries (guint		 n_entries,
-					      GtkMenuEntry      *entries);
-void	gtk_item_factories_path_delete	   (const gchar		*ifactory_path,
-					    const gchar		*path);
+
+/* Used by gtk_item_factory_callback_marshal () */
 typedef	void	(*GtkItemFactoryCallback2) (GtkWidget		*widget,
 					    gpointer		 callback_data,
 					    guint		 callback_action);
+
+/* Used by gtk_item_factory_create_items () */
 void	gtk_item_factory_create_items_ac (GtkItemFactory	*ifactory,
 					  guint			 n_entries,
 					  GtkItemFactoryEntry	*entries,
 					  gpointer		 callback_data,
 					  guint			 callback_type);
-#endif /* GTK_DISABLE_DEPRECATED */
+
+GtkItemFactory*	gtk_item_factory_from_path   (const gchar       *path);
+void	gtk_item_factory_create_menu_entries (guint		 n_entries,
+					      GtkMenuEntry      *entries);
+void	gtk_item_factories_path_delete	   (const gchar		*ifactory_path,
+					    const gchar		*path);
+
+#endif /* !GTK_DISABLE_DEPRECATED || GTK_COMPILATION */
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+G_END_DECLS
 
 #endif	/* __GTK_ITEM_FACTORY_H__ */
+
