@@ -646,8 +646,8 @@ _gtk_scale_format_value (GtkScale *scale,
   if (fmt)
     return fmt;
   else
-    return g_strdup_printf ("%0.*f", scale->digits,
-                            value);
+    /* insert a LRM, to prevent -20 to come out as 20- in RTL locales */
+    return g_strdup_printf ("\342\200\216%0.*f", scale->digits, value);
 }
 
 static void
@@ -722,7 +722,8 @@ gtk_scale_get_layout_offsets (GtkScale *scale,
                               gint     *x,
                               gint     *y)
 {
-  gint local_x, local_y;
+  gint local_x = 0;
+  gint local_y = 0;
 
   g_return_if_fail (GTK_IS_SCALE (scale));
 
