@@ -1415,16 +1415,16 @@ gtk_selection_data_get_pixbuf (GtkSelectionData *selection_data)
     {
       loader = gdk_pixbuf_loader_new ();
       
-      if (gdk_pixbuf_loader_write (loader, 
-				   selection_data->data,
-				   selection_data->length,
-				   NULL))
-	result = gdk_pixbuf_loader_get_pixbuf (loader);
+      gdk_pixbuf_loader_write (loader, 
+			       selection_data->data,
+			       selection_data->length,
+			       NULL);
+      gdk_pixbuf_loader_close (loader, NULL);
+      result = gdk_pixbuf_loader_get_pixbuf (loader);
       
       if (result)
 	g_object_ref (result);
       
-      gdk_pixbuf_loader_close (loader, NULL);
       g_object_unref (loader);
     }
 
@@ -1475,6 +1475,8 @@ gtk_selection_data_set_uris (GtkSelectionData  *selection_data,
 	  gtk_selection_data_set (selection_data,
 				  text_uri_list_atom,
 				  8, (guchar *)result, length);
+
+	  g_free (result);
 	  
 	  return TRUE;
 	}
@@ -1517,9 +1519,7 @@ gtk_selection_data_get_uris (GtkSelectionData *selection_data)
       if (count > 0)
 	result = g_uri_list_extract_uris (list[0]);
       
-      for (i = 1; i < count; i++)
-	g_free (list[i]);
-      g_free (list);
+      g_strfreev (list);
     }
 
   return result;
@@ -1831,6 +1831,8 @@ _gtk_selection_request (GtkWidget *widget,
 	      info->conversions[i].property = gdk_x11_xatom_to_atom_for_display (display,
 										 ((glong *)mult_atoms)[2*i + 1]);
 	    }
+
+	  g_free (mult_atoms);
 	}
       else
 #endif
